Sports Items | Boston Herald
Description: Chrome Industries' Mini Buran laptop messenger bag ($140) is a good in
Keywords: Chrome Industries, Sports Items, Gift Guide
Date: 2014-12-16T22:25:00-05:00

Skip to main content

# Sports Items

# Chrome Industries' Mini Buran laptop messenger bag is meant to last

##

Tuesday, December 16, 2014
Print Email Comments

### By:

Sean Griffin

###

Chrome Industries' Mini Buran laptop messenger bag ($140) is a good investment for anyone who needs a sturdy bag that is built to last and can contain all of your stuff, whether it be a thin laptop or iPad. There are also small pockets for lighter objects.

The article you requested has been archived
All coverage within bostonherald.com from the last 14 days remains free of charge. Articles do not always include original photos, charts or graphics.
» Click here to search for this article within the archive.

### More On:

Chrome Industries

### Author(s):

### Sean Griffin

## Advertisement

## f645ad45a591c4a717067dcdf6c9ffd6.jpg

### Photo by:

Unknown
1

## Advertisement